Predict for burgle methods
# S3 method for burgle_CauseSpecificCox
predict(
object,
newdata = NULL,
type = "lp",
cause = 1,
original = TRUE,
draws = 1,
sims = 1,
times = NULL,
...
)# S3 method for burgle_cph
predict(object, ...)
# S3 method for burgle_flexsurvreg
predict(
object,
newdata = NA,
original = TRUE,
draws = 1,
sims = 1,
type = "lp",
times = NULL,
...
)
# S3 method for burgle_multinom
predict(
object,
newdata = NA,
original = TRUE,
draws = 1,
sims = 1,
type = "lp",
floor = FALSE,
seed = NULL,
...
)
# S3 method for burgle_coxph
predict(
object,
newdata = NA,
original = TRUE,
draws = 1,
sims = 1,
type = "lp",
times = NULL,
...
)
# S3 method for burgle_lm
predict(
object,
newdata,
original = TRUE,
draws = 1,
sims = 1,
type = "lp",
se = FALSE,
limits = NULL,
...
)
# S3 method for burgle_glm
predict(
object,
newdata,
original = TRUE,
draws = 1,
sims = 1,
type = "lp",
se = FALSE,
...
)
either a matrix or list of new model predictions
the results of burgle_* object
new data of class data.frame
either 'lp', 'response', 'link' for glm or 'risk' if time dependent
which cause do you want to predict
whether or not to predict using the original model
how many different models to simulate
how many simulated response to draw
if type = "risk" time for which to predict risk, if times and sims is multiple the return will be lists within lists
for future methods
will set the minimum odds to 0, if negative odds exists
a seed to specificy for simulating responses (multinomial only)
whether or not to include the standard error in the simulations
limits (minimum and maximum) for simulated response values.